==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/classwxPLplotwindow.js <==
var classwxPLplotwindow =
[
    [ "wxPLplotwindow", "classwxPLplotwindow.html#a04e9404bd092d669e9eb69d8fcf41699", null ],
    [ "~wxPLplotwindow", "classwxPLplotwindow.html#ad9ca072bd52da411d42224523496c81b", null ],
    [ "GetStream", "classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa", null ],
    [ "IsReady", "classwxPLplotwindow.html#a4a49b4d5858afbe931550601e3d0eada", null ],
    [ "OnCreate", "classwxPLplotwindow.html#a09fe8cf92d3ccae0e58f1dd92051d684", null ],
    [ "OnErase", "classwxPLplotwindow.html#ad184b76db6081d2e4bdde5f6854eca7c", null ],
    [ "OnLocate", "classwxPLplotwindow.html#ae608afb8eef92ad95814e7242b9726dc", null ],
    [ "OnMouse", "classwxPLplotwindow.html#af2547b13630e6f3cabdedd5520749a2a", null ],
    [ "OnPaint", "classwxPLplotwindow.html#a53f657e3771b953d80ad077e7add1594", null ],
    [ "OnSize", "classwxPLplotwindow.html#aa4b386e34069cb93a2c47d9e986eb8bb", null ],
    [ "RenewPlot", "classwxPLplotwindow.html#a0f746b49cc3f84810c303129910bfd5f", null ],
    [ "SavePlot", "classwxPLplotwindow.html#ae99d46aef176670c2a2419a92d93820e", null ],
    [ "setCanvasColour", "classwxPLplotwindow.html#a7747711787ac35165188b66af175041c", null ],
    [ "setUseGraphicsContext", "classwxPLplotwindow.html#a240f1acd3f8144e28219954b470b514b", null ],
    [ "m_bitmap", "classwxPLplotwindow.html#a448fc7b678fe9300e09a0ec4845aceb6", null ],
    [ "m_canvasColour", "classwxPLplotwindow.html#a56a3fc5e70ab0b4288d405eba3221103", null ],
    [ "m_created", "classwxPLplotwindow.html#ae146662e19866daab2746062529f6da6", null ],
    [ "m_initialSize", "classwxPLplotwindow.html#a0c105bec0e7cdf1c4431b3c9eb2c4e3c", null ],
    [ "m_memoryDc", "classwxPLplotwindow.html#a431044cf4a70a2aa3802a7ca585590f7", null ],
    [ "m_stream", "classwxPLplotwindow.html#a4a24892a8539fcbe23dfa2f22c886798", null ],
    [ "m_useGraphicsContext", "classwxPLplotwindow.html#af4600d45758ea7ade4dda619782431be", null ]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/classwxPLplotwindow.js <==
var classwxPLplotwindow =
[
    [ "wxPLplotwindow", "classwxPLplotwindow.html#a2e7b6d356400176b1a6cb8de6563d8bf", null ],
    [ "~wxPLplotwindow", "classwxPLplotwindow.html#ad9ca072bd52da411d42224523496c81b", null ],
    [ "GetStream", "classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa", null ],
    [ "IsReady", "classwxPLplotwindow.html#a4a49b4d5858afbe931550601e3d0eada", null ],
    [ "OnCreate", "classwxPLplotwindow.html#a09fe8cf92d3ccae0e58f1dd92051d684", null ],
    [ "OnErase", "classwxPLplotwindow.html#ad184b76db6081d2e4bdde5f6854eca7c", null ],
    [ "OnLocate", "classwxPLplotwindow.html#ae608afb8eef92ad95814e7242b9726dc", null ],
    [ "OnMouse", "classwxPLplotwindow.html#af2547b13630e6f3cabdedd5520749a2a", null ],
    [ "OnPaint", "classwxPLplotwindow.html#a53f657e3771b953d80ad077e7add1594", null ],
    [ "OnRenderTimer", "classwxPLplotwindow.html#acf4e5bc3c1e276955ce66109e412c565", null ],
    [ "OnSize", "classwxPLplotwindow.html#aa4b386e34069cb93a2c47d9e986eb8bb", null ],
    [ "RenewPlot", "classwxPLplotwindow.html#a0f746b49cc3f84810c303129910bfd5f", null ],
    [ "SavePlot", "classwxPLplotwindow.html#ae99d46aef176670c2a2419a92d93820e", null ],
    [ "setCanvasColour", "classwxPLplotwindow.html#a7747711787ac35165188b66af175041c", null ],
    [ "setUseGraphicsContext", "classwxPLplotwindow.html#a240f1acd3f8144e28219954b470b514b", null ],
    [ "ID_RENDERTIMER", "classwxPLplotwindow.html#a2021b7dda6c44f94f0b63d19653241d8", null ],
    [ "m_bitmap", "classwxPLplotwindow.html#a448fc7b678fe9300e09a0ec4845aceb6", null ],
    [ "m_canvasColour", "classwxPLplotwindow.html#a56a3fc5e70ab0b4288d405eba3221103", null ],
    [ "m_completedFirstRender", "classwxPLplotwindow.html#adaf0ac116110117160cf12032693bb92", null ],
    [ "m_created", "classwxPLplotwindow.html#ae146662e19866daab2746062529f6da6", null ],
    [ "m_initialSize", "classwxPLplotwindow.html#a0c105bec0e7cdf1c4431b3c9eb2c4e3c", null ],
    [ "m_memoryDc", "classwxPLplotwindow.html#a431044cf4a70a2aa3802a7ca585590f7", null ],
    [ "m_renderTimer", "classwxPLplotwindow.html#a0a0311aad5868724e2e2bb354f6a530a", null ],
    [ "m_resizeRenderDelay", "classwxPLplotwindow.html#ab4ccae324d7f297aba5c4c7e0631cd2c", null ],
    [ "m_resizing", "classwxPLplotwindow.html#a0aae6eeecc957a6a44b35e3dd6a40b61", null ],
    [ "m_stream", "classwxPLplotwindow.html#a4a24892a8539fcbe23dfa2f22c886798", null ],
    [ "m_useGraphicsContext", "classwxPLplotwindow.html#af4600d45758ea7ade4dda619782431be", null ]
];
